==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Exception/Log.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::Log::BEGIN{package Exception::Log;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::Log::BEGIN{package Exception::Log;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub Exception::Log::notify{package 
Exception::Log;no warnings;(my $self=shift (@_));(my $statusId=
main::get_unique_id ());($statusId=~ s/(........).*/$1/ );
Common::NXMsg::send_response (
"\x65\x78\x70\x4c\x6f\x67\x46\x61\x74\x61\x6c\x45\x72\x72\x6f\x72\x31");
Common::NXMsg::send_response (
"\x65\x78\x70\x4c\x6f\x67\x46\x61\x74\x61\x6c\x45\x72\x72\x6f\x72\x32",$statusId
);Common::NXMsg::send_response (
"\x65\x78\x70\x4c\x6f\x67\x46\x61\x74\x61\x6c\x45\x72\x72\x6f\x72\x33",$statusId
);Common::NXMsg::send_response (
"\x65\x78\x70\x4c\x6f\x67\x46\x61\x74\x61\x6c\x45\x72\x72\x6f\x72\x34",
Logger::logFilePath ());(my $trace=$self->stacktrace);($trace=~ s/\n[^\w]+/\n/ )
;($trace=~ s/\t//gm );(my (@aTrace)=split ( /\n/ ,$trace,(0x1603+ 3475-0x2396)))
;Logger::multilineLog (((
"\x28\x65\x78\x63\x65\x70\x74\x69\x6f\x6e\x20\x69\x64\x20".$statusId)."\x29"),
@aTrace);}package Exception::Log;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Exception/Log.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::Log::BEGIN{package Exception::Log;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::Log::BEGIN{package Exception::Log;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub Exception::Log::notify{package 
Exception::Log;no warnings;(my $self=shift (@_));(my $statusId=
main::get_unique_id ());($statusId=~ s/(........).*/$1/ );
Common::NXMsg::send_response (
"\x65\x78\x70\x4c\x6f\x67\x46\x61\x74\x61\x6c\x45\x72\x72\x6f\x72\x31");
Common::NXMsg::send_response (
"\x65\x78\x70\x4c\x6f\x67\x46\x61\x74\x61\x6c\x45\x72\x72\x6f\x72\x32",$statusId
);Common::NXMsg::send_response (
"\x65\x78\x70\x4c\x6f\x67\x46\x61\x74\x61\x6c\x45\x72\x72\x6f\x72\x33",$statusId
);Common::NXMsg::send_response (
"\x65\x78\x70\x4c\x6f\x67\x46\x61\x74\x61\x6c\x45\x72\x72\x6f\x72\x34",
Logger::logFilePath ());(my $trace=$self->stacktrace);($trace=~ s/\n[^\w]+/\n/ )
;($trace=~ s/\t//gm );(my (@aTrace)=split ( /\n/ ,$trace,(0x0f0f+ 4354-0x2011)))
;Logger::multilineLog (((
"\x28\x65\x78\x63\x65\x70\x74\x69\x6f\x6e\x20\x69\x64\x20".$statusId)."\x29"),
@aTrace);}package Exception::Log;no warnings;"\x3f\x3f\x3f";
